pandasdmx\.reader package
=========================

Submodules
----------

pandasdmx\.reader\.sdmxjson module
----------------------------------

.. automodule:: pandasdmx.reader.sdmxjson
    :members:
    :undoc-members:
    :show-inheritance:

pandasdmx\.reader\.sdmxml module
--------------------------------

.. automodule:: pandasdmx.reader.sdmxml
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: pandasdmx.reader
    :members:
    :undoc-members:
    :show-inheritance:
